@@ -31,6 +31,7 @@
 #define EDJE_1_22_SUPPORTED " -DEFL_VERSION_1_22=1 "
 #define EDJE_1_23_SUPPORTED " -DEFL_VERSION_1_23=1 "
 #define EDJE_1_24_SUPPORTED " -DEFL_VERSION_1_24=1 "
+#define EDJE_1_25_SUPPORTED " -DEFL_VERSION_1_25=1 "
 
 #define EDJE_CC_EFL_VERSION_SUPPORTED \
   EDJE_1_18_SUPPORTED                 \
@@ -39,7 +40,8 @@
   EDJE_1_21_SUPPORTED                 \
   EDJE_1_22_SUPPORTED                 \
   EDJE_1_23_SUPPORTED                 \
-  EDJE_1_24_SUPPORTED
+  EDJE_1_24_SUPPORTED                 \
+  EDJE_1_25_SUPPORTED
 
 static void        new_object(void);
 static void        new_statement(void);
