@@ -7,31 +7,38 @@ typedef struct _App_Data
 {
    Efl_Canvas_Animation        *cw_45_degrees_anim;
    Efl_Canvas_Animation        *ccw_45_degrees_anim;
-   Efl_Canvas_Animation_Player *anim_obj;
+   Elm_Button                  *button;
 
    Eina_Bool             is_btn_rotated;
 } App_Data;
 
 static void
-_anim_started_cb(void *data EINA_UNUSED, const Efl_Event *event EINA_UNUSED)
+_anim_changed_cb(void *data EINA_UNUSED, const Efl_Event *event EINA_UNUSED)
 {
-   printf("Animation has been started!\n");
-}
+   Eo *anim = event->info;
 
-static void
-_anim_ended_cb(void *data EINA_UNUSED, const Efl_Event *event EINA_UNUSED)
-{
-   printf("Animation has been ended!\n");
+   if (anim)
+     {
+        printf("Animation has been started!\n");
+     }
+   else
+     {
+        printf("Animation has been ended!\n");
+     }
 }
 
 static void
 _anim_running_cb(void *data EINA_UNUSED, const Efl_Event *event)
 {
-   Efl_Canvas_Animation_Player_Event_Running *event_running = event->info;
-   double progress = event_running->progress;
-   printf("Animation is running! Current progress(%lf)\n", progress);
+   double *progress = event->info;
+   printf("Animation is running! Current progress(%lf)\n", *progress);
 }
 
+EFL_CALLBACKS_ARRAY_DEFINE(animation_stats_cb,
+  {EFL_CANVAS_OBJECT_ANIMATION_EVENT_ANIMATION_CHANGED, _anim_changed_cb },
+  {EFL_CANVAS_OBJECT_ANIMATION_EVENT_ANIMATION_PROGRESS_UPDATED, _anim_running_cb },
+)
+
 static void
 _btn_clicked_cb(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
@@ -42,18 +49,15 @@ _btn_clicked_cb(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
    if (ad->is_btn_rotated)
      {
         //Create Animation Object from Animation
-        efl_animation_player_animation_set(ad->anim_obj, ad->cw_45_degrees_anim);
+        efl_canvas_object_animation_start(ad->button, ad->cw_45_degrees_anim, 1.0, 0.0);
         efl_text_set(obj, "Start Rotate Animation from 45 to 0 degrees");
      }
    else
      {
         //Create Animation Object from Animation
-        efl_animation_player_animation_set(ad->anim_obj, ad->ccw_45_degrees_anim);
+        efl_canvas_object_animation_start(ad->button, ad->ccw_45_degrees_anim, 1.0, 0.0);
         efl_text_set(obj, "Start Rotate Animation from 0 to 45 degrees");
      }
-
-   //Let Animation Object start animation
-   efl_player_playing_set(ad->anim_obj, EINA_TRUE);
 }
 
 static void
@@ -81,32 +85,24 @@ test_efl_anim_rotate(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void
    evas_object_resize(btn, 150, 150);
    evas_object_move(btn, 125, 100);
    evas_object_show(btn);
+   efl_event_callback_array_add(btn, animation_stats_cb(), ad);
 
    //Rotate from 0 to 45 degrees Animation
-   Efl_Canvas_Animation *cw_45_degrees_anim = efl_add(EFL_CANVAS_ANIMATION_ROTATE_CLASS, win);
-   efl_animation_rotate_set(cw_45_degrees_anim, 0.0, 45.0,NULL, 0.5, 0.5);
+   Efl_Canvas_Animation *cw_45_degrees_anim = efl_add(EFL_CANVAS_ROTATE_ANIMATION_CLASS, win);
+   efl_animation_rotate_set(cw_45_degrees_anim, 0.0, 45.0, NULL, EINA_VECTOR2(0.5, 0.5));
    efl_animation_duration_set(cw_45_degrees_anim, 1.0);
    efl_animation_final_state_keep_set(cw_45_degrees_anim, EINA_TRUE);
 
    //Rotate from 45 to 0 degrees Animation
-   Efl_Canvas_Animation *ccw_45_degrees_anim = efl_add(EFL_CANVAS_ANIMATION_ROTATE_CLASS, win);
-   efl_animation_rotate_set(ccw_45_degrees_anim, 45.0, 0.0, NULL, 0.5, 0.5);
+   Efl_Canvas_Animation *ccw_45_degrees_anim = efl_add(EFL_CANVAS_ROTATE_ANIMATION_CLASS, win);
+   efl_animation_rotate_set(ccw_45_degrees_anim, 45.0, 0.0, NULL, EINA_VECTOR2(0.5, 0.5));
    efl_animation_duration_set(ccw_45_degrees_anim, 1.0);
    efl_animation_final_state_keep_set(ccw_45_degrees_anim, EINA_TRUE);
 
    //Initialize App Data
    ad->cw_45_degrees_anim = cw_45_degrees_anim;
    ad->ccw_45_degrees_anim = ccw_45_degrees_anim;
-
-   ad->anim_obj = efl_add(EFL_CANVAS_ANIMATION_PLAYER_CLASS, win,
-                          efl_animation_player_target_set(efl_added, btn));
-   //Register callback called when animation starts
-   efl_event_callback_add(ad->anim_obj, EFL_ANIMATION_PLAYER_EVENT_STARTED, _anim_started_cb, NULL);
-   //Register callback called when animation ends
-   efl_event_callback_add(ad->anim_obj, EFL_ANIMATION_PLAYER_EVENT_ENDED, _anim_ended_cb, NULL);
-   //Register callback called while animation is executed
-   efl_event_callback_add(ad->anim_obj, EFL_ANIMATION_PLAYER_EVENT_RUNNING, _anim_running_cb, NULL);
-
+   ad->button = btn;
    ad->is_btn_rotated = EINA_FALSE;
 
    //Button to start animation
@@ -140,6 +136,7 @@ test_efl_anim_rotate_relative(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUS
    evas_object_resize(btn, 150, 150);
    evas_object_move(btn, 125, 100);
    evas_object_show(btn);
+   efl_event_callback_array_add(btn, animation_stats_cb(), ad);
 
    //Pivot to be center of the rotation
    Evas_Object *pivot = elm_button_add(win);
@@ -150,32 +147,22 @@ test_efl_anim_rotate_relative(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUS
    evas_object_show(pivot);
 
    //Rotate from 0 to 45 degrees Animation
-   Efl_Canvas_Animation *cw_45_degrees_anim = efl_add(EFL_CANVAS_ANIMATION_ROTATE_CLASS, win);
-   efl_animation_rotate_set(cw_45_degrees_anim, 0.0, 45.0, pivot, 0.5, 0.5);
+   Efl_Canvas_Animation *cw_45_degrees_anim = efl_add(EFL_CANVAS_ROTATE_ANIMATION_CLASS, win);
+   efl_animation_rotate_set(cw_45_degrees_anim, 0.0, 45.0, pivot, EINA_VECTOR2(0.5, 0.5));
    efl_animation_duration_set(cw_45_degrees_anim, 1.0);
    efl_animation_final_state_keep_set(cw_45_degrees_anim, EINA_TRUE);
 
    //Rotate from 45 to 0 degrees Animation
-   Efl_Canvas_Animation *ccw_45_degrees_anim = efl_add(EFL_CANVAS_ANIMATION_ROTATE_CLASS, win);
-   efl_animation_rotate_set(ccw_45_degrees_anim, 45.0, 0.0, pivot, 0.5, 0.5);
+   Efl_Canvas_Animation *ccw_45_degrees_anim = efl_add(EFL_CANVAS_ROTATE_ANIMATION_CLASS, win);
+   efl_animation_rotate_set(ccw_45_degrees_anim, 45.0, 0.0, pivot, EINA_VECTOR2(0.5, 0.5));
    efl_animation_duration_set(ccw_45_degrees_anim, 1.0);
    efl_animation_final_state_keep_set(ccw_45_degrees_anim, EINA_TRUE);
 
    //Initialize App Data
    ad->cw_45_degrees_anim = cw_45_degrees_anim;
    ad->ccw_45_degrees_anim = ccw_45_degrees_anim;
-   ad->anim_obj = efl_add(EFL_CANVAS_ANIMATION_PLAYER_CLASS, win,
-                          efl_animation_player_target_set(efl_added, btn));
-
-   //Register callback called when animation starts
-   efl_event_callback_add(ad->anim_obj, EFL_ANIMATION_PLAYER_EVENT_STARTED, _anim_started_cb, NULL);
-
-   //Register callback called when animation ends
-   efl_event_callback_add(ad->anim_obj, EFL_ANIMATION_PLAYER_EVENT_ENDED, _anim_ended_cb, NULL);
-
-   //Register callback called while animation is executed
-   efl_event_callback_add(ad->anim_obj, EFL_ANIMATION_PLAYER_EVENT_RUNNING, _anim_running_cb, NULL);
    ad->is_btn_rotated = EINA_FALSE;
+   ad->button = btn;
 
    //Button to start animation
    Evas_Object *btn2 = elm_button_add(win);
@@ -208,6 +195,7 @@ test_efl_anim_rotate_absolute(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUS
    evas_object_resize(btn, 150, 150);
    evas_object_move(btn, 125, 100);
    evas_object_show(btn);
+   efl_event_callback_array_add(btn, animation_stats_cb(), ad);
 
    //Absolute coordinate (0, 0) to be center of the rotation
    Evas_Object *abs_center = elm_button_add(win);
@@ -218,31 +206,22 @@ test_efl_anim_rotate_absolute(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUS
    evas_object_show(abs_center);
 
    //Rotate from 0 to 45 degrees Animation
-   Efl_Canvas_Animation *cw_45_degrees_anim = efl_add(EFL_CANVAS_ANIMATION_ROTATE_CLASS, win);
-   efl_animation_rotate_absolute_set(cw_45_degrees_anim, 0.0, 45.0, 0, 0);
+   Efl_Canvas_Animation *cw_45_degrees_anim = efl_add(EFL_CANVAS_ROTATE_ANIMATION_CLASS, win);
+   efl_animation_rotate_absolute_set(cw_45_degrees_anim, 0.0, 45.0, EINA_POSITION2D(0, 0));
    efl_animation_duration_set(cw_45_degrees_anim, 1.0);
    efl_animation_final_state_keep_set(cw_45_degrees_anim, EINA_TRUE);
 
    //Rotate from 45 to 0 degrees Animation
-   Efl_Canvas_Animation *ccw_45_degrees_anim = efl_add(EFL_CANVAS_ANIMATION_ROTATE_CLASS, win);
-   efl_animation_rotate_absolute_set(ccw_45_degrees_anim, 45.0, 0.0, 0, 0);
+   Efl_Canvas_Animation *ccw_45_degrees_anim = efl_add(EFL_CANVAS_ROTATE_ANIMATION_CLASS, win);
+   efl_animation_rotate_absolute_set(ccw_45_degrees_anim, 45.0, 0.0, EINA_POSITION2D(0, 0));
    efl_animation_duration_set(ccw_45_degrees_anim, 1.0);
    efl_animation_final_state_keep_set(ccw_45_degrees_anim, EINA_TRUE);
 
    //Initialize App Data
    ad->cw_45_degrees_anim = cw_45_degrees_anim;
    ad->ccw_45_degrees_anim = ccw_45_degrees_anim;
-   ad->anim_obj = efl_add(EFL_CANVAS_ANIMATION_PLAYER_CLASS, win,
-                          efl_animation_player_target_set(efl_added, btn));
-
-   //Register callback called when animation starts
-   efl_event_callback_add(ad->anim_obj, EFL_ANIMATION_PLAYER_EVENT_STARTED, _anim_started_cb, NULL);
-   //Register callback called when animation ends
-   efl_event_callback_add(ad->anim_obj, EFL_ANIMATION_PLAYER_EVENT_ENDED, _anim_ended_cb, NULL);
-   //Register callback called while animation is executed
-   efl_event_callback_add(ad->anim_obj, EFL_ANIMATION_PLAYER_EVENT_RUNNING, _anim_running_cb, NULL);
-
    ad->is_btn_rotated = EINA_FALSE;
+   ad->button = btn;
 
    //Button to start animation
    Evas_Object *btn2 = elm_button_add(win);
