@@ -5,7 +5,7 @@
 #include <Elementary.h>
 
 #define EFL_INTERNAL_UNSTABLE
-#include "interfaces/efl_common_internal.h"
+#include "Evas_Internal.h"
 
 #define DEFAULT_TEXT "Click the white rectangle to get started"
 
