@@ -3,7 +3,7 @@
 #endif
 #include <Efl_Ui.h>
 #include <Elementary.h>
-#include "elm_priv.h" //FIXME remove this once efl.ui.text doesn't need elm_general.h
+
 static const struct {
  Evas_Image_Orient orient;
  const char *name;
@@ -150,10 +150,6 @@ my_bt_open(void *data, Evas_Object *obj EINA_UNUSED, void *event_info)
 
         eina_list_free(grps);
      }
-
-   if (file && eina_str_has_extension(file, ".gif")
-       && efl_playable_get(ph))
-     efl_player_playing_set(ph, EINA_TRUE);
 }
 
 static void
@@ -179,7 +175,7 @@ my_bt_zoom_in(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UN
      zoom -= 0.5;
    else if ((zoom > 1.0) && (zoom <= 1.5))
      zoom = 1.0;
-   else if (zoom == 1.0)
+   else if (EINA_DBL_EQ(zoom, 1.0))
      zoom = 0.8;
    else
      zoom = zoom * zoom;
@@ -805,7 +801,7 @@ test_image_zoomable_animated(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSE
    Eo *win, *bx, *zoomable, *rect;
    char buf[PATH_MAX];
 
-   win = efl_add_ref(EFL_UI_WIN_CLASS, NULL,
+   win = efl_add(EFL_UI_WIN_CLASS, efl_main_loop_get(),
                                   efl_text_set(efl_added, "Efl.Ui.Image_Zoomable animation"),
                  efl_ui_win_autodel_set(efl_added, EINA_TRUE));
 
@@ -813,11 +809,13 @@ test_image_zoomable_animated(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSE
                 efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL),
                 efl_content_set(win, efl_added));
 
-   efl_add(EFL_UI_TEXT_CLASS, bx,
+   efl_add(EFL_UI_TEXTBOX_CLASS, bx,
            efl_text_set(efl_added, "Clicking the image will play/pause animation."),
            efl_text_interactive_editable_set(efl_added, EINA_FALSE),
            efl_gfx_hint_weight_set(efl_added, 1, 0),
-           efl_canvas_text_style_set(efl_added, NULL, "DEFAULT='align=center font=Sans font_size=10 color=#fff wrap=word'"),
+           efl_text_font_family_set(efl_added, "Sans"),
+           efl_text_font_size_set(efl_added, 10),
+           efl_text_color_set(efl_added, 255, 255, 255, 255),
            efl_pack(bx, efl_added)
           );
 
@@ -832,7 +830,8 @@ test_image_zoomable_animated(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSE
    if (efl_playable_get(zoomable))
      {
         printf("animation is available for this image.\n");
-        efl_player_playing_set(zoomable, EINA_TRUE);
+        efl_player_autoplay_set(zoomable, EINA_TRUE);
+        efl_player_playback_loop_set(zoomable, EINA_TRUE);
      }
 
    rect = efl_add(EFL_CANVAS_RECTANGLE_CLASS, win,
